@@ -1,23 +1,14 @@
 package Data::Storage::DBI::SQLite;
-
-# $Id: SQLite.pm 9190 2005-06-14 14:47:46Z gr $
-
 use strict;
 use warnings;
-
-
-our $VERSION = '0.09';
-
-
+our $VERSION = '0.10';
 use base 'Data::Storage::DBI';
 
-
 sub connect_string {
     my $self = shift;
     sprintf("dbi:SQLite:dbname=%s", $self->dbname);
 }
 
-
 # Prepare a test database; unlink the existing database and recreate it with
 # the initial data. This method is called at the beginning of test programs.
 # The functionality implemented here is specific to SQLite, as that's probably
@@ -25,31 +16,24 @@ sub connect_string {
 # where setup is going to take a lot more steps than unlinking and recreating,
 # you might want to prepare a test database beforehand and leave this method
 # empty, so the same database is reused for many tests.
-
 sub test_setup {
     my $self = shift;
-
     if (-e $self->dbname) {
-        unlink $self->dbname or
-            throw Error::Hierarchy::Internal::CustomMessage(custom_message =>
-                sprintf "can't unlink %s: %s\n", $self->dbname, $!
-            );
+        unlink $self->dbname
+          or throw Error::Hierarchy::Internal::CustomMessage(
+            custom_message => sprintf "can't unlink %s: %s\n",
+            $self->dbname, $!
+          );
     }
-
     $self->connect;
     $self->setup;
 }
 
-
 sub last_id {
     my $self = shift;
     $self->dbh->func('last_insert_rowid');
 }
-
-
 1;
-
-
 __END__
 
 
@@ -167,7 +151,7 @@ See perlmodinstall for information and options on installing Perl modules.
 
 The latest version of this module is available from the Comprehensive Perl
 Archive Network (CPAN). Visit <http://www.perl.com/CPAN/> to find a CPAN
-site near you. Or see <http://www.perl.com/CPAN/authors/id/M/MA/MARCEL/>.
+site near you. Or see L<http://search.cpan.org/dist/Data-Storage/>.
 
 =head1 AUTHORS
 
@@ -175,7 +159,7 @@ Marcel GrE<uuml>nauer, C<< <marcel@cpan.org> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2004-2008 by the authors.
+Copyright 2004-2009 by the authors.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
