@@ -1,51 +1,30 @@
 package Data::Storage::Mock;
-
-# $Id: Mock.pm 13653 2007-10-22 09:11:20Z gr $
-
 use strict;
 use warnings;
-
-
-our $VERSION = '0.09';
-
-
+our $VERSION = '0.10';
 use base qw(Data::Storage Class::Accessor::Complex);
-
-
 __PACKAGE__->mk_scalar_accessors(qw(should_die_on_connect));
 
-
 sub connect {
     my $self = shift;
     $self->die_on_connect if $self->should_die_on_connect;
 }
 
-
 sub die_on_connect {
     my $self = shift;
-    throw Error::Hierarchy::Internal::CustomMessage(custom_message =>
-        "can't connect",
-    );
+    throw Error::Hierarchy::Internal::CustomMessage(
+        custom_message => "can't connect",);
 }
 
-
 sub disconnect {
     my $self = shift;
     return unless $self->is_connected;
     $self->rollback_mode ? $self->rollback : $self->commit;
 }
-
-
 sub is_connected { 1 }
-
-
-sub rollback {}
-sub commit   {}
-
-
+sub rollback     { }
+sub commit       { }
 1;
-
-
 __END__
 
 
@@ -67,13 +46,13 @@ next release will have more documentation.
 
 =over 4
 
-=item clear_should_die_on_connect
+=item C<clear_should_die_on_connect>
 
     $obj->clear_should_die_on_connect;
 
 Clears the value.
 
-=item should_die_on_connect
+=item C<should_die_on_connect>
 
     my $value = $obj->should_die_on_connect;
     $obj->should_die_on_connect($value);
@@ -81,7 +60,7 @@ Clears the value.
 A basic getter/setter method. If called without an argument, it returns the
 value. If called with a single argument, it sets the value.
 
-=item should_die_on_connect_clear
+=item C<should_die_on_connect_clear>
 
     $obj->should_die_on_connect_clear;
 
@@ -166,7 +145,7 @@ See perlmodinstall for information and options on installing Perl modules.
 
 The latest version of this module is available from the Comprehensive Perl
 Archive Network (CPAN). Visit <http://www.perl.com/CPAN/> to find a CPAN
-site near you. Or see <http://www.perl.com/CPAN/authors/id/M/MA/MARCEL/>.
+site near you. Or see L<http://search.cpan.org/dist/Data-Storage/>.
 
 =head1 AUTHORS
 
@@ -174,7 +153,7 @@ Marcel GrE<uuml>nauer, C<< <marcel@cpan.org> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2004-2008 by the authors.
+Copyright 2004-2009 by the authors.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
